
GarpixCMS
=========

Start new project with GarpixCMS
--------------------------------

.. code-block:: bash

   pip install cookiecutter

   cookiecutter https://github.com/garpixcms/garpixcms-empty-template

   # Enter name for your website...

   cd website

   # See README.md of project

   cat README.md

Changelog
=========

See `CHANGELOG.md <CHANGELOG.md>`_.

Contributing
============

See `CONTRIBUTING.md <CONTRIBUTING.md>`_.

License
=======

`MIT <LICENSE>`_
